@@ -45,7 +45,7 @@ define!({
         pub raw: JsWord,
     }
 
-    pub struct Num {
+    pub struct Number {
         pub span: Span,
         pub value: f64,
         pub raw: JsWord,
@@ -84,16 +84,14 @@ define!({
     pub enum Value {
         SimpleBlock(SimpleBlock),
 
-        SquareBracketBlock(SquareBracketBlock),
-
-        RoundBracketBlock(RoundBracketBlock),
-
         Unit(UnitValue),
 
-        Number(Num),
+        Number(Number),
 
         Percent(PercentValue),
 
+        Ratio(Ratio),
+
         Hash(HashValue),
 
         Ident(Ident),
@@ -108,13 +106,11 @@ define!({
 
         Comma(CommaValues),
 
-        Brace(BraceValue),
-
-        Lazy(Tokens),
+        Tokens(Tokens),
 
         AtText(AtTextValue),
 
-        Url(UrlValue),
+        Url(Url),
     }
 
     pub struct SpaceValues {
@@ -143,16 +139,6 @@ define!({
         pub value: Vec<Value>,
     }
 
-    pub struct RoundBracketBlock {
-        pub span: Span,
-        pub children: Option<Vec<Value>>,
-    }
-
-    pub struct SquareBracketBlock {
-        pub span: Span,
-        pub children: Option<Vec<Value>>,
-    }
-
     pub struct HashValue {
         pub span: Span,
         pub value: JsWord,
@@ -161,32 +147,50 @@ define!({
 
     pub struct UnitValue {
         pub span: Span,
-        pub value: Num,
+        pub value: Number,
         pub unit: Unit,
     }
 
     pub struct PercentValue {
         pub span: Span,
-        pub value: Num,
+        pub value: Number,
     }
 
-    pub struct BraceValue {
+    pub struct Ratio {
         pub span: Span,
-        pub value: Box<Value>,
+        pub left: Number,
+        pub right: Option<Number>,
     }
 
     pub struct AtTextValue {
         pub span: Span,
         pub name: Ident,
-        pub block: Option<BraceValue>,
+        pub block: Option<SimpleBlock>,
     }
 
-    pub struct UrlValue {
+    pub struct Url {
         pub span: Span,
-        pub url: JsWord,
+        pub name: Ident,
+        pub value: Option<UrlValue>,
+        pub modifiers: Option<Vec<UrlModifier>>,
+    }
+
+    pub enum UrlValue {
+        Str(Str),
+        Raw(UrlValueRaw),
+    }
+
+    pub struct UrlValueRaw {
+        pub span: Span,
+        pub value: JsWord,
         pub raw: JsWord,
     }
 
+    pub enum UrlModifier {
+        Ident(Ident),
+        Function(Function),
+    }
+
     pub struct SelectorList {
         pub span: Span,
         pub children: Vec<ComplexSelector>,
@@ -344,8 +348,7 @@ define!({
     }
 
     pub enum ImportHref {
-        Function(Function),
-        Url(UrlValue),
+        Url(Url),
         Str(Str),
     }
 
@@ -373,7 +376,7 @@ define!({
     }
 
     pub enum NamespaceUri {
-        Url(UrlValue),
+        Url(Url),
         Str(Str),
     }
 
@@ -527,10 +530,10 @@ define!({
     }
 
     pub enum MediaFeatureValue {
-        Number(Num),
+        Number(Number),
         Dimension(UnitValue),
         Ident(Ident),
-        Ratio(BinValue),
+        Ratio(Ratio),
     }
 
     pub struct MediaFeaturePlain {
